class Danila_vagon_text_recognize_params:
    def __init__(self, vagon_text_recognize_version, vagon_text_recognize_size_h, vagon_text_recognize_size_w):
        self.vagon_text_recognize_version = vagon_text_recognize_version
        self.vagon_text_recognize_size_h = vagon_text_recognize_size_h
        self.vagon_text_recognize_size_w = vagon_text_recognize_size_w