class Danila_balka_text_recognize_prod_redone:

    def __init__(self, danila_balka_text_recognize):
        self.danila_balka_text_recognize = danila_balka_text_recognize

    def balka_text_recognize(self, balka_prod, img_cut, image_text_areas):
        return self.danila_balka_text_recognize.balka_text_recognize(balka_prod, img_cut, image_text_areas)

