class Danila_balka_params:
    def __init__(self, danila_balka_classify_params, danila_balka_detect_params, danila_balka_text_recognize_params):
        self.danila_balka_classify_params = danila_balka_classify_params
        self.danila_balka_text_detect_params = danila_balka_detect_params
        self.danila_balka_text_recognize_params = danila_balka_text_recognize_params