LOCAL_RAMA_BEGICKAYA_DETECT_MODEL_ADDRESS = 'models/rama_detect/rama_begickaya_detect.pt'
LOCAL_RAMA_RUZHIMMASH_DETECT_MODEL_ADDRESS = 'models/rama_detect/rama_ruzhimmash_detect_weights.pt'
LOCAL_RAMA_RUZHIMMASH_DETECT_MODEL_ADDRESS_2 = 'models/rama_detect/rama_ruzhimmash_detect_2.pt'
LOCAL_RAMA_ALTAI_DETECT_MODEL_ADDRESS = 'models/rama_detect/rama_altai_detect_300.pt'
LOCAL_RAMA_ALTAI_DETECT_MODEL_ADDRESS_2 = 'models/rama_detect/rama_altai_detect_400.pt'
LOCAL_RAMA_BALAKOVO_DETECT_MODEL_ADDRESS = 'models/rama_detect/rama_balakovo_detect.pt'
LOCAL_RAMA_PROMLIT_DETECT_MODEL_ADDRESS = 'models/rama_detect/rama_promlit_detect_300.pt'
LOCAL_RAMA_PROMLIT_DETECT_MODEL_ADDRESS_2 = 'models/rama_detect/rama_promlit_detect_600.pt'
LOCAL_RAMA_TIHVIN_DETECT_MODEL_ADDRESS = 'models/rama_detect/rama_tihvin_detect.pt'
LOCAL_RAMA_URALVAGON_DETECT_MODEL_ADDRESS = 'models/rama_detect/rama_uralvagon_detect.pt'
LOCAL_RAMA_DETECT_MODEL_ADDRESS = 'models/rama_detect/rama_detect.pt'

LOCAL_RAMA_ALTAI_TEXT_DETECT_MODEL_ADDRESS = 'models/rama_text_detect/rama_altai_text_detect.pt'
LOCAL_RAMA_ALTAI_TEXT_DETECT_MODEL_ADDRESS_2 = 'models/rama_text_detect/rama_altai_text_detect_400.pt'
LOCAL_RAMA_BALAKOVO_TEXT_DETECT_MODEL_ADDRESS = 'models/rama_text_detect/rama_balakovo_text_detect.pt'
LOCAL_RAMA_BEGICKAYA_TEXT_DETECT_MODEL_ADDRESS = 'models/rama_text_detect/rama_begickaya_text_detect.pt'
LOCAL_RAMA_PROMLIT_TEXT_DETECT_MODEL_ADDRESS = 'models/rama_text_detect/rama_promlit_text_detect.pt'
LOCAL_RAMA_PROMLIT_TEXT_DETECT_MODEL_ADDRESS_2 = 'models/rama_text_detect/rama_promlit_text_detect_600.pt'
LOCAL_RAMA_RUZHIMMASH_TEXT_DETECT_MODEL_ADDRESS = 'models/rama_text_detect/rama_ruzhimmash_text_detect.pt'
LOCAL_RAMA_RUZHIMMASH_TEXT_DETECT_MODEL_ADDRESS_2 = 'models/rama_text_detect/rama_ruzhimmash_text_detect_2.pt'
LOCAL_RAMA_TIHVIN_TEXT_DETECT_MODEL_ADDRESS = 'models/rama_text_detect/rama_tihvin_text_detect.pt'
LOCAL_RAMA_URALVAGON_TEXT_DETECT_MODEL_ADDRESS = 'models/rama_text_detect/rama_uralvagon_text_detect.pt'

LOCAL_RAMA_TEXT_RECOGNIZE_MODEL_ADDRESS = 'models/rama_text_recognize/rama_b_r_text_recognize.pt' # 11000_b_11000_r
LOCAL_RAMA_TEXT_RECOGNIZE_MODEL_ADDRESS_2 = 'models/rama_text_recognize/rama_a_b_r_text_recognize.pt' # 5000_a_11000_b_11000_r
LOCAL_RAMA_TEXT_RECOGNIZE_MODEL_ADDRESS_3 = 'models/rama_text_recognize/rama_a_b_p_r_t_text_recognize.pt' # 5000_a_11000_b_2000_p_11000_r_5000_t
LOCAL_RAMA_TEXT_RECOGNIZE_MODEL_ADDRESS_4 = 'models/rama_text_recognize/rama_balka_all_text_recognize.pt'
LOCAL_RAMA_TEXT_RECOGNIZE_MODEL_ADDRESS_5 = 'models/rama_text_recognize/rama_balka_all_2_text_recognize.pt'

LOCAL_RAMA_PROD_CLASSIFY_MODEL_ADDRESS = 'https://disk.yandex.ru/d/8FI8TaTwaCfbSA'
LOCAL_RAMA_PROD_CLASSIFY_MODEL_ADDRESS_2 = 'models/rama_classify/model_3500.pt'
LOCAL_RAMA_PROD_CLASSIFY_MODEL_ADDRESS_3 = 'models/rama_classify/model_4000.pt'
LOCAL_RAMA_PROD_CLASSIFY_MODEL_ADDRESS_4 = 'models/rama_classify/model_4200.pt'
LOCAL_RAMA_PROD_CLASSIFY_MODEL_ADDRESS_5 = 'models/rama_classify/model_4200_n.pt'
LOCAL_VAGON_NUMBER_DETECT_MODEL_ADDRESS = 'models/vagon_number_detect/vagon_number_detect.pt'
LOCAL_VAGON_NUMBER_DETECT_MODEL_ADDRESS_2 = 'models/vagon_number_detect/vagon_number_detect_2.pt'

LOCAL_VAGON_NUMBER_RECOGNIZE_MODEL_ADDRESS = 'models/vagon_number_recognize/06_10_6000_im/exp39/weights/text_recognize_yolo.pt'
LOCAL_VAGON_NUMBER_RECOGNIZE_MODEL_ADDRESS_2 = 'models/vagon_number_recognize/06_16_9000_im/exp41/weights/text_recognize_yolo.pt'
LOCAL_VAGON_NUMBER_RECOGNIZE_MODEL_ADDRESS_3 = 'models/vagon_number_recognize/06_16_22000_im/exp40/weights/text_recognize_yolo.pt'
LOCAL_VAGON_NUMBER_RECOGNIZE_MODEL_ADDRESS_4 = 'models/vagon_number_recognize/06_20_9500_im/exp43/weights/text_recognize_yolo.pt'

LOCAL_BALKA_CLASSIFY_MODEL_ADDRESS = 'models/balka_classify/balka_classify_1500.pt'
LOCAL_BALKA_CLASSIFY_MODEL_ADDRESS_2 = 'models/balka_classify/balka_classify_10000.pt'

LOCAL_BALKA_DETECT_MODEL_ADDRESS = 'models/balka_detect/balka_detect/balka_detect.pt'
LOCAL_BALKA_ALTAI_DETECT_MODEL_ADDRESS = 'models/balka_detect/balka_altai_detect/balka_altai_detect.pt'
LOCAL_BALKA_ALTAI_DETECT_MODEL_ADDRESS_2 = 'models/balka_detect/balka_altai_detect/balka_altai_detect_1000.pt'
LOCAL_BALKA_ALTAI_DETECT_MODEL_ADDRESS_3 = 'models/balka_detect/balka_altai_detect/balka_altai_detect_2000.pt'
LOCAL_BALKA_BEGICKAYA_DETECT_MODEL_ADDRESS = 'models/balka_detect/balka_begickaya_detect/balka_begickaya_detect.pt'
LOCAL_BALKA_PROMLIT_DETECT_MODEL_ADDRESS = 'models/balka_detect/balka_promlit_detect/balka_detect.pt'
LOCAL_BALKA_RUZHIMMASH_DETECT_MODEL_ADDRESS = 'models/balka_detect/balka_ruzhimmash_detect/balka_detect.pt'
LOCAL_BALKA_TIHVIN_DETECT_MODEL_ADDRESS = 'models/balka_detect/balka_tihvin_detect/balka_detect.pt'

LOCAL_BALKA_ALTAI_TEXT_DETECT_MODEL_ADDRESS = 'models/balka_text_detect/balka_altai_text_detect/balka_altai_text_detect.pt'
LOCAL_BALKA_ALTAI_TEXT_DETECT_MODEL_ADDRESS_2 = 'models/balka_text_detect/balka_altai_text_detect/balka_altai_text_detect_2000.pt'
LOCAL_BALKA_ALTAI_TEXT_DETECT_MODEL_ADDRESS_3 = 'models/balka_text_detect/balka_altai_text_detect/balka_altai_5_text_detect.pt'
LOCAL_BALKA_BEGICKAYA_TEXT_DETECT_MODEL_ADDRESS = 'models/balka_text_detect/balka_begickaya_text_detect/balka_begickaya_text_detect.pt'
LOCAL_BALKA_BEGICKAYA_TEXT_DETECT_MODEL_ADDRESS_2 = 'models/balka_text_detect/balka_begickaya_text_detect/balka_begickaya_text_detect_2.pt'
LOCAL_BALKA_PROMLIT_TEXT_DETECT_MODEL_ADDRESS = 'models/balka_text_detect/balka_promlit_text_detect/balka_promlit_text_detect.pt'
LOCAL_BALKA_PROMLIT_TEXT_DETECT_MODEL_ADDRESS_2 = 'models/balka_text_detect/balka_promlit_text_detect/balka_promlit_text_detect_2.pt'
LOCAL_BALKA_RUZHIMMASH_TEXT_DETECT_MODEL_ADDRESS = 'models/balka_text_detect/balka_ruzhimmash_text_detect/balka_ruzhimmash_text_detect.pt'
LOCAL_BALKA_TIHVIN_TEXT_DETECT_MODEL_ADDRESS = 'models/balka_text_detect/balka_tihvin_text_detect/balka_tihvin_text_detect.pt'
LOCAL_BALKA_TIHVIN_TEXT_DETECT_MODEL_ADDRESS_2 = 'models/balka_text_detect/balka_tihvin_text_detect/balka_tihvin_4_text_detect.pt'

LOCAL_DETAIL_CLASSIFY_MODEL_ADDRESS = 'https://disk.yandex.ru/d/Xamk_OYzYAbGhg'
LOCAL_DETAIL_CLASSIFY_MODEL_ADDRESS_2 = 'models/detail_classify/detail_classify_balka/detail_classify_model.h5'
LOCAL_DETAIL_CLASSIFY_YOLO_MODEL_ADDRESS = 'models/detail_classify/detail_classify_4500/detail_classify.pt'
LOCAL_DETAIL_CLASSIFY_BALKA_MODEL_ADDRESS = LOCAL_BALKA_PROMLIT_DETECT_MODEL_ADDRESS
LOCAL_DETAIL_CLASSIFY_RAMA_MODEL_ADDRESS = LOCAL_RAMA_BALAKOVO_DETECT_MODEL_ADDRESS
LOCAL_DETAIL_CLASSIFY_VAGON_MODEL_ADDRESS = LOCAL_VAGON_NUMBER_DETECT_MODEL_ADDRESS

