RAMA_CLASSIFY_MODEL_ADDRESS = 'https://disk.yandex.ru/d/4xtNt0zftHFFVg'

RAMA_BEGICKAYA_DETECT_MODEL_ADDRESS = 'https://disk.yandex.ru/d/dld9TFyEQGWBcw'
RAMA_RUZHIMMASH_DETECT_MODEL_ADDRESS = 'https://disk.yandex.ru/d/42sWB5wc7iCZgQ'
RAMA_RUZHIMMASH_DETECT_MODEL_ADDRESS_2 = 'https://disk.yandex.ru/d/7lAoRbs6HUkLaA'
RAMA_ALTAI_DETECT_MODEL_ADDRESS = 'https://disk.yandex.ru/d/q3FDt5wzdjCg7Q'
RAMA_ALTAI_DETECT_MODEL_ADDRESS_2 = 'https://disk.yandex.ru/d/klpSwrGiS9T0OQ'
RAMA_BALAKOVO_DETECT_MODEL_ADDRESS = 'https://disk.yandex.ru/d/HlcViPdjY2hS5g'
RAMA_PROMLIT_DETECT_MODEL_ADDRESS = 'https://disk.yandex.ru/d/wRdF0UOdGoXlVQ'
RAMA_PROMLIT_DETECT_MODEL_ADDRESS_2 ='https://disk.yandex.ru/d/r631dRw9gzKQAQ'
RAMA_TIHVIN_DETECT_MODEL_ADDRESS = 'https://disk.yandex.ru/d/8xJz_9PsUDH41Q'
RAMA_URALVAGON_DETECT_MODEL_ADDRESS = 'https://disk.yandex.ru/d/QK7sDnJDisNJiQ'

RAMA_ALTAI_TEXT_DETECT_MODEL_ADDRESS = 'https://disk.yandex.ru/d/Pb4cNl3JxcUw6Q'
RAMA_ALTAI_TEXT_DETECT_MODEL_ADDRESS_2 = 'https://disk.yandex.ru/d/izG9zUipd3Ws5Q'
RAMA_BALAKOVO_TEXT_DETECT_MODEL_ADDRESS = 'https://disk.yandex.ru/d/bitLjF_wboq26Q'
RAMA_BEGICKAYA_TEXT_DETECT_MODEL_ADDRESS = 'https://disk.yandex.ru/d/nQaiB6YheVSc7Q'
RAMA_PROMLIT_TEXT_DETECT_MODEL_ADDRESS = 'https://disk.yandex.ru/d/lu11fYVSW64k6A'
RAMA_PROMLIT_TEXT_DETECT_MODEL_ADDRESS_2 = 'https://disk.yandex.ru/d/wISY6tAbHNpg4g'
RAMA_RUZHIMMASH_TEXT_DETECT_MODEL_ADDRESS = 'https://disk.yandex.ru/d/B5brahwfJhy9mg'
RAMA_RUZHIMMASH_TEXT_DETECT_MODEL_ADDRESS_2 = 'https://disk.yandex.ru/d/UZdPspStE0SAHA'
RAMA_TIHVIN_TEXT_DETECT_MODEL_ADDRESS = 'https://disk.yandex.ru/d/fbQL7mq1wV6ueA'
RAMA_URALVAGON_TEXT_DETECT_MODEL_ADDRESS = 'https://disk.yandex.ru/d/HZH6SabldzFSkQ'

# RAMA_TEXT_RECOGNIZE_MODEL_ADDRESS = 'https://disk.yandex.ru/d/C2hDMsbTZMnL8Q' -7500_b7500_r
# TEXT_RECOGNIZE_BEGICKAYA_MODEL_ADDRESS = 'https://disk.yandex.ru/d/C2hDMsbTZMnL8Q'
RAMA_TEXT_RECOGNIZE_MODEL_ADDRESS = 'https://disk.yandex.ru/d/GcI-mAtwpb2I-g' # 11000_b_11000_r
RAMA_TEXT_RECOGNIZE_MODEL_ADDRESS_2 = 'https://disk.yandex.ru/d/hhvxqKMaSgFJMA' # 5000_a_11000_b_11000_r


RAMA_PROD_CLASSIFY_MODEL_ADDRESS = 'https://disk.yandex.ru/d/8FI8TaTwaCfbSA'
RAMA_PROD_CLASSIFY_MODEL_ADDRESS_2 = 'https://disk.yandex.ru/d/P7rKubXWHJjgCQ'
RAMA_PROD_CLASSIFY_MODEL_ADDRESS_3 = 'https://disk.yandex.ru/d/41FTqiZhIW_Ytg'
VAGON_NUMBER_DETECT_MODEL_ADDRESS = 'https://disk.yandex.ru/d/ZGS0sdk1syJmcQ'
VAGON_NUMBER_DETECT_MODEL_ADDRESS_2 = 'https://disk.yandex.ru/d/3artWauJULaWXw'

VAGON_NUMBER_RECOGNIZE_MODEL_ADDRESS = 'https://disk.yandex.ru/d/eh714_PrjFyLHg'
VAGON_NUMBER_RECOGNIZE_MODEL_ADDRESS_2 = 'https://disk.yandex.ru/d/iZxGW6ZaXZDoQQ'
VAGON_NUMBER_RECOGNIZE_MODEL_ADDRESS_3 = 'https://disk.yandex.ru/d/wd697DtHumhsjA'
VAGON_NUMBER_RECOGNIZE_MODEL_ADDRESS_4 = 'https://disk.yandex.ru/d/4UqcWigCF5hCqw'

BALKA_CLASSIFY_MODEL_ADDRESS = 'https://disk.yandex.ru/d/B0sdDuJQnmR9ZA'

BALKA_ALTAI_DETECT_MODEL_ADDRESS = 'https://disk.yandex.ru/d/7JLCBgAC3hH4jw'
BALKA_BEGICKAYA_DETECT_MODEL_ADDRESS = 'https://disk.yandex.ru/d/NBIl4fwZkrQaZA'
BALKA_PROMLIT_DETECT_MODEL_ADDRESS = 'https://disk.yandex.ru/d/g-aW6tMTsrI9Iw'
BALKA_RUZHIMMASH_DETECT_MODEL_ADDRESS = 'https://disk.yandex.ru/d/WVEld5fLliy-SA'
BALKA_TIHVIN_DETECT_MODEL_ADDRESS = 'https://disk.yandex.ru/d/ItUmCGqM5p5j9g'

BALKA_ALTAI_TEXT_DETECT_MODEL_ADDRESS = 'https://disk.yandex.ru/d/E2AMY5EW1W3AsQ'
BALKA_BEGICKAYA_TEXT_DETECT_MODEL_ADDRESS = 'https://disk.yandex.ru/d/BUmrhYaD08oGGw'
BALKA_PROMLIT_TEXT_DETECT_MODEL_ADDRESS = 'https://disk.yandex.ru/d/dgJW0CcYQe2q0A'
BALKA_RUZHIMMASH_TEXT_DETECT_MODEL_ADDRESS = 'https://disk.yandex.ru/d/M8Wz2z420XPpBw'
BALKA_TIHVIN_TEXT_DETECT_MODEL_ADDRESS = 'https://disk.yandex.ru/d/X0_WRNJfOreOsQ'

DETAIL_CLASSIFY_MODEL_ADDRESS = 'https://disk.yandex.ru/d/Xamk_OYzYAbGhg'
DETAIL_CLASSIFY_MODEL_ADDRESS_2 = 'https://disk.yandex.ru/d/_t4r3N7a2Uy3cA'
DETAIL_CLASSIFY_YOLO_MODEL_ADDRESS = 'https://disk.yandex.ru/d/2VNw___O_k0J_A'
DETAIL_CLASSIFY_BALKA_MODEL_ADDRESS = BALKA_PROMLIT_DETECT_MODEL_ADDRESS
DETAIL_CLASSIFY_RAMA_MODEL_ADDRESS = RAMA_BALAKOVO_DETECT_MODEL_ADDRESS
DETAIL_CLASSIFY_VAGON_MODEL_ADDRESS = VAGON_NUMBER_DETECT_MODEL_ADDRESS

